@@ -5,16 +5,16 @@ our $VERSION = '5.27';
 use strict;
 use warnings;
 
-use lib "lib";
-
 use Cwd;
 use Carp;
 use English qw( -no_match_vars );
 use File::Copy;
+use File::Path;
 use Params::Validate qw(:all);
 use Scalar::Util qw( openhandle );
 use URI;
 
+use lib 'lib';
 use vars qw/ $fatal_err $err $log /;
 
 sub new {
@@ -396,7 +396,7 @@ sub cwd_source_dir {
 
 sub _try_mkdir {
     my ( $dir ) = @_;
-    mkdir $dir, oct('0755') 
+    mkpath( $dir, 0, 0755) 
         or return $log->error( "mkdir $dir failed: $!");
     $log->audit( "created $dir");
     return 1;
@@ -545,7 +545,6 @@ sub file_get {
     };
 
     return if ! -e $file_path;
-
     return $response;
 }
 
@@ -904,7 +903,7 @@ sub find_bin {
         return $found;
     }
 
-    $log->error( "WARNING: could not find $bin", %std_args) if $debug;
+    $log->error( "could not find $bin", %std_args) if $debug;
     return;
 }
 
@@ -1021,7 +1020,7 @@ sub get_dir_files {
 sub get_my_ips {
 
     ############################################
-    # Usage      : @list_of_ips_ref = $utility->get_my_ips();
+    # Usage      : @list_of_ips_ref = $util->get_my_ips();
     # Purpose    : get a list of IP addresses on local interfaces
     # Returns    : an arrayref of IP addresses
     # Parameters : only - can be one of: first, last
@@ -1359,8 +1358,7 @@ sub install_from_source {
     my $self = shift;
     my %p = validate(
         @_,
-        {   'conf'           => { type => HASHREF,  optional => 1, },
-            'site'           => { type => SCALAR,   optional => 0, },
+        {   'site'           => { type => SCALAR,   optional => 0, },
             'url'            => { type => SCALAR,   optional => 0, },
             'package'        => { type => SCALAR,   optional => 0, },
             'targets'        => { type => ARRAYREF, optional => 1, },
@@ -1377,11 +1375,11 @@ sub install_from_source {
 
     return $p{test_ok} if defined $p{test_ok};
 
-    my ( $conf, $site, $url, $package, $targets, $patches, $debug, $bintest ) =
-        ( $p{conf},    $p{site},    $p{url}, $p{package},
+    my ( $site, $url, $package, $targets, $patches, $debug, $bintest ) =
+        ( $p{site},    $p{url}, $p{package},
           $p{targets}, $p{patches}, $p{debug}, $p{bintest} );
 
-    my $src = $conf->{toaster_src_dir} || "/usr/local/src";
+    my $src = "/usr/local/src";
     $src .= "/$p{source_sub_dir}" if $p{source_sub_dir};
 
     my %std_args = ( debug => $p{debug}, fatal => $p{fatal} );
@@ -1420,7 +1418,6 @@ sub install_from_source {
 
     #print "install_from_source: looking for existing sources...";
     $self->sources_get(
-        conf    => $conf,
         package => $package,
         site    => $site,
         url     => $url,
@@ -1433,9 +1430,10 @@ sub install_from_source {
 
     PATCH:
         foreach my $patch (@$patches) {
+            next if ! $patch;
             next PATCH if -e $patch;
 
-            my $url = "$p{patch_url}/$patch",
+            my $url = "$p{patch_url}/$patch";
             $self->file_get(
                 url   => $url,
                 debug => $debug,
@@ -1557,6 +1555,12 @@ sub install_package {
 sub install_module {
     my ($self, $module, $info) = @_;
 
+    eval "use $module";
+    if ( ! $EVAL_ERROR ) {
+        $log->audit( "$module is already installed." );
+        return 1;
+    };
+
     if ( lc($OSNAME) eq 'darwin' ) {
         my $dport = '/opt/local/bin/port';
         return $log->error( "Darwin ports is not installed!", fatal => 0)
@@ -1569,8 +1573,11 @@ sub install_module {
 
     if ( lc($OSNAME) eq 'freebsd' ) {
 
-        my $portname = "p5-$module";
-        $portname =~ s/::/-/g;
+        my $portname = $info->{port}; # optional override
+        if ( ! $portname ) {
+            $portname = "p5-$module";
+            $portname =~ s/::/-/g;
+        };
 
         if (`/usr/sbin/pkg_info | /usr/bin/grep $portname`) {
             print "$module is installed.\n";
@@ -1608,6 +1615,80 @@ sub install_module {
     use warnings;
 
     CPAN::Shell->install($module);
+
+    eval "use $module";
+    if ( ! $EVAL_ERROR ) {
+        $log->audit( "$module is installed." );
+        return 1;
+    };
+}
+
+sub install_module_from_src {
+    my $self = shift;
+    my %p = validate( @_, {
+            module  => { type=>SCALAR,  optional=>0, },
+            archive => { type=>SCALAR,  optional=>0, },
+            site    => { type=>SCALAR,  optional=>0, },
+            url     => { type=>SCALAR,  optional=>0, },
+            src     => { type=>SCALAR,  optional=>1, default=>'/usr/local/src' },
+            targets => { type=>ARRAYREF,optional=>1, },
+            fatal   => { type=>BOOLEAN, optional=>1, default=>1 },
+            debug   => { type=>BOOLEAN, optional=>1, default=>1 },
+        },
+    );
+
+    my ( $module, $site, $url, $src, $targets, $debug )
+        = ( $p{module}, $p{site}, $p{url}, $p{src}, $p{targets}, $p{debug} );
+    my %std_args = ( debug => $p{debug}, fatal => $p{fatal} );
+
+    $self->cwd_source_dir( dir => $src, %std_args );
+
+    $log->audit( "checking for previous build attempts.");
+    if ( -d $module ) {
+        if ( ! $self->source_warning( package=>$module, src=>$src, %std_args ) ) {
+            carp "\nokay, skipping install.\n";
+            return;
+        }
+        $self->syscmd( cmd => "rm -rf $module", %std_args );
+    }
+
+    $self->sources_get(
+        site    => $site,
+        url     => $url,
+        package => $p{'archive'} || $module,
+        %std_args,
+    ) or return;
+
+    $self->archive_expand( archive => $module, %std_args) or return;
+
+    my $found;
+    print "looking for $module in $src...";
+    foreach my $file ( $self->get_dir_files( dir => $src ) ) {
+
+        next if ! -d $file;  # only check directories
+        next if $file !~ /$module/;
+
+        print "found: $file\n";
+        $found++;
+        chdir $file;
+
+        unless ( @$targets[0] && @$targets[0] ne "" ) {
+            $log->audit( "using default targets." );
+            $targets = [ "perl Makefile.PL", "make", "make install" ];
+        }
+
+        print "building with targets " . join( ", ", @$targets ) . "\n";
+        foreach (@$targets) {
+            return $log->error( "$_ failed!", %std_args)
+                if ! $self->syscmd( cmd => $_ , %std_args);
+        }
+
+        chdir('..');
+        $self->syscmd( cmd => "rm -rf $file", debug=>0);
+        last;
+    }
+
+    return $found;
 }
 
 sub is_interactive {
@@ -1659,10 +1740,10 @@ sub is_process_running {
     my $ps   = $self->find_bin( 'ps',   debug => 0 );
     my $grep = $self->find_bin( 'grep', debug => 0 );
 
-    if    ( lc($OSNAME) =~ /solaris/i ) { $ps .= " -ef";  }
-    elsif ( lc($OSNAME) =~ /irix/i    ) { $ps .= " -ef";  }
-    elsif ( lc($OSNAME) =~ /linux/i   ) { $ps .= " -efw"; }
-    else                                { $ps .= " axw";  };
+    if    ( lc($OSNAME) =~ /solaris/i ) { $ps .= ' -ef';  }
+    elsif ( lc($OSNAME) =~ /irix/i    ) { $ps .= ' -ef';  }
+    elsif ( lc($OSNAME) =~ /linux/i   ) { $ps .= ' -efw'; }
+    else                                { $ps .= ' axw';  };
 
     my $is_running = `$ps | $grep $process | $grep -v grep` ? 1 : 0;
     #warn "$ps | $grep $process | $grep -v grep\n" if ! $is_running;
@@ -1972,8 +2053,8 @@ sub sources_get {
         },
     );
 
-    my ( $conf, $package, $site, $url, $debug )
-        = ( $p{conf}, $p{package}, $p{site}, $p{url}, $p{debug} );
+    my ( $package, $site, $url, $debug )
+        = ( $p{package}, $p{site}, $p{url}, $p{debug} );
 
     my %std_args = ( debug => $p{debug}, fatal => $p{fatal} );
 
@@ -2161,7 +2242,7 @@ sub syscmd {
     }
     else {
         # make sure it does not not contain a ./ pattern
-        if ( $cmd!~ m{\./} ) {
+        if ( $cmd !~ m{\./} ) {
             $bin = $cmd;
             $is_safe++;
         }
@@ -2340,9 +2421,9 @@ Provision::Unix::Utility - utility subroutines for sysadmin tasks
 =head1 SYNOPSIS
 
   use Provision::Unix::Utility;
-  my $utility = Provision::Unix::Utility->new;
+  my $util = Provision::Unix::Utility->new;
 
-  $utility->file_write($file, @lines);
+  $util->file_write($file, @lines);
 
 This is just one of the many handy little methods I have amassed here. Rather than try to remember all of the best ways to code certain functions and then attempt to remember them, I have consolidated years of experience and countless references from Learning Perl, Programming Perl, Perl Best Practices, and many other sources into these subroutines.
 
@@ -2380,7 +2461,7 @@ To use any of the methods below, you must first create a utility object. The met
 
   ############################################
   # Usage      : use Provision::Unix::Utility;
-  #            : my $utility = Provision::Unix::Utility->new;
+  #            : my $util = Provision::Unix::Utility->new;
   # Purpose    : create a new Provision::Unix::Utility object
   # Returns    : a bona fide object
   # Parameters : none
@@ -2393,7 +2474,7 @@ To use any of the methods below, you must first create a utility object. The met
 Get a response from the user. If the user responds, their response is returned. If not, then the default response is returned. If no default was supplied, 0 is returned.
 
   ############################################
-  # Usage      :  my $ask = $utility->ask( "Would you like fries with that",
+  # Usage      :  my $ask = $util->ask( "Would you like fries with that",
   #  		           default  => "SuperSized!",
   #  		           timeout  => 30  
   #               );
@@ -2417,7 +2498,7 @@ Get a response from the user. If the user responds, their response is returned.
 Decompresses a variety of archive formats using your systems built in tools.
 
   ############### archive_expand ##################
-  # Usage      : $utility->archive_expand(
+  # Usage      : $util->archive_expand(
   #            :     archive => 'example.tar.bz2' );
   # Purpose    : test the archiver, determine its contents, and then
   #              use the best available means to expand it.
@@ -2431,7 +2512,7 @@ Decompresses a variety of archive formats using your systems built in tools.
 Changes the current working directory to the supplied one. Creates it if it does not exist. Tries to create the directory using perl's builtin mkdir, then the system mkdir, and finally the system mkdir with sudo. 
 
   ############ cwd_source_dir ###################
-  # Usage      : $utility->cwd_source_dir( dir=>"/usr/local/src" );
+  # Usage      : $util->cwd_source_dir( dir=>"/usr/local/src" );
   # Purpose    : prepare a location to build source files in
   # Returns    : 0 - failure,  1 - success
   # Parameters : S - dir - a directory to build programs in
@@ -2442,7 +2523,7 @@ Changes the current working directory to the supplied one. Creates it if it does
 Checks the ownership on all home directories to see if they are owned by their respective users in /etc/password. Offers to repair the permissions on incorrectly owned directories. This is useful when someone that knows better does something like "chown -R user /home /user" and fouls things up.
 
   ######### check_homedir_ownership ############
-  # Usage      : $utility->check_homedir_ownership();
+  # Usage      : $util->check_homedir_ownership();
   # Purpose    : repair user homedir ownership
   # Returns    : 0 - failure,  1 - success
   # Parameters :
@@ -2462,7 +2543,7 @@ The advantage this sub has over a Pure Perl implementation is that it can utiliz
 
 
   ############### chown_system #################
-  # Usage      : $utility->chown_system( dir=>"/tmp/example", user=>'matt' );
+  # Usage      : $util->chown_system( dir=>"/tmp/example", user=>'matt' );
   # Purpose    : change the ownership of a file or directory
   # Returns    : 0 - failure,  1 - success
   # Parameters : S - dir    - the directory to chown
@@ -2477,7 +2558,7 @@ The advantage this sub has over a Pure Perl implementation is that it can utiliz
 
 
   ############## clean_tmp_dir ################
-  # Usage      : $utility->clean_tmp_dir( dir=>$dir );
+  # Usage      : $util->clean_tmp_dir( dir=>$dir );
   # Purpose    : clean up old build stuff before rebuilding
   # Returns    : 0 - failure,  1 - success
   # Parameters : S - $dir - a directory or file. 
@@ -2488,7 +2569,7 @@ The advantage this sub has over a Pure Perl implementation is that it can utiliz
 =item get_mounted_drives
 
   ############# get_mounted_drives ############
-  # Usage      : my $mounts = $utility->get_mounted_drives();
+  # Usage      : my $mounts = $util->get_mounted_drives();
   # Purpose    : Uses mount to fetch a list of mounted drive/partitions
   # Returns    : a hashref of mounted slices and their mount points.
 
@@ -2498,7 +2579,7 @@ The advantage this sub has over a Pure Perl implementation is that it can utiliz
 
   ############### file_archive #################
   # Purpose    : Make a backup copy of a file by copying the file to $file.timestamp.
-  # Usage      : my $archived_file = $utility->file_archive( file=>$file );
+  # Usage      : my $archived_file = $util->file_archive( file=>$file );
   # Returns    : the filename of the backup file, or 0 on failure.
   # Parameters : S - file - the filname to be backed up
   # Comments   : none
@@ -2508,7 +2589,7 @@ The advantage this sub has over a Pure Perl implementation is that it can utiliz
 
 Set the permissions (ugo-rwx) of a file. Will use the native perl methods (by default) but can also use system calls and prepend sudo if additional permissions are needed.
 
-  $utility->chmod(
+  $util->chmod(
 		file_or_dir => '/etc/resolv.conf',
 		mode => '0755',
 		sudo => $sudo
@@ -2519,7 +2600,7 @@ Set the permissions (ugo-rwx) of a file. Will use the native perl methods (by de
    mode   - the permissions (numeric)
 
  arguments optional:
-   sudo  - the output of $utility->sudo
+   sudo  - the output of $util->sudo
    fatal - die on errors? (default: on)
    debug
 
@@ -2532,7 +2613,7 @@ Set the permissions (ugo-rwx) of a file. Will use the native perl methods (by de
 
 Set the ownership (user and group) of a file. Will use the native perl methods (by default) but can also use system calls and prepend sudo if additional permissions are needed.
 
-  $utility->chown(
+  $util->chown(
 		file_or_dir => '/etc/resolv.conf',
 		uid => 'root',
 		gid => 'wheel',
@@ -2547,7 +2628,7 @@ Set the ownership (user and group) of a file. Will use the native perl methods (
  arguments optional:
    file  - alias for file_or_dir
    dir   - alias for file_or_dir
-   sudo  - the output of $utility->sudo
+   sudo  - the output of $util->sudo
    fatal - die on errors? (default: on)
    debug
 
@@ -2559,7 +2640,7 @@ Set the ownership (user and group) of a file. Will use the native perl methods (
 =item file_delete
 
   ############################################
-  # Usage      : $utility->file_delete( file=>$file );
+  # Usage      : $util->file_delete( file=>$file );
   # Purpose    : Deletes a file.
   # Returns    : 0 - failure, 1 - success
   # Parameters 
@@ -2572,7 +2653,7 @@ Set the ownership (user and group) of a file. Will use the native perl methods (
 
 =item file_get
 
-   $utility->file_get( url=>$url, debug=>1 );
+   $util->file_get( url=>$url, debug=>1 );
 
 Use the standard URL fetching utility (fetch, curl, wget) for your OS to download a file from the $url handed to us.
 
@@ -2598,9 +2679,9 @@ compares the mtime on two files to determine if one is newer than another.
 
  usage:
    my @lines = "1", "2", "3";  # named array
-   $utility->file_write ( file=>"/tmp/foo", lines=>\@lines );   
+   $util->file_write ( file=>"/tmp/foo", lines=>\@lines );   
         or
-   $utility->file_write ( file=>"/tmp/foo", lines=>['1','2','3'] );  # anon arrayref
+   $util->file_write ( file=>"/tmp/foo", lines=>['1','2','3'] );  # anon arrayref
 
  required arguments:
    mode - the files permissions mode
@@ -2618,7 +2699,7 @@ compares the mtime on two files to determine if one is newer than another.
 
 Reads in a file, and returns it in an array. All lines in the array are chomped.
 
-   my @lines = $utility->file_read( file=>$file, max_lines=>100 )
+   my @lines = $util->file_read( file=>$file, max_lines=>100 )
 
  arguments required:
    file - the file to read in
@@ -2638,9 +2719,9 @@ Reads in a file, and returns it in an array. All lines in the array are chomped.
 
  usage:
    my @lines = "1", "2", "3";  # named array
-   $utility->file_write ( file=>"/tmp/foo", lines=>\@lines );   
+   $util->file_write ( file=>"/tmp/foo", lines=>\@lines );   
         or
-   $utility->file_write ( file=>"/tmp/foo", lines=>['1','2','3'] );  # anon arrayref
+   $util->file_write ( file=>"/tmp/foo", lines=>['1','2','3'] );  # anon arrayref
 
  required arguments:
    file - the file path you want to write to
@@ -2659,9 +2740,9 @@ Reads in a file, and returns it in an array. All lines in the array are chomped.
 
 Determine if the files are different. $type is assumed to be text unless you set it otherwise. For anthing but text files, we do a MD5 checksum on the files to determine if they are different or not.
 
-   $utility->files_diff( f1=>$file1,f2=>$file2,type=>'text',debug=>1 );
+   $util->files_diff( f1=>$file1,f2=>$file2,type=>'text',debug=>1 );
 
-   if ( $utility->files_diff( f1=>"foo", f2=>"bar" ) )
+   if ( $util->files_diff( f1=>"foo", f2=>"bar" ) )
    {
        print "different!\n";
    };
@@ -2681,48 +2762,15 @@ Determine if the files are different. $type is assumed to be text unless you set
   -1 - error.
 
 
-=item find_config
-
-This sub is called by several others to determine which configuration file to use. The general logic is as follows:
-
-  If the etc dir and file name are provided and the file exists, use it.
-
-If that fails, then go prowling around the drive and look in all the usual places, in order of preference:
-
-  /opt/local/etc/
-  /usr/local/etc/
-  /etc
-
-Finally, if none of those work, then check the working directory for the named .conf file, or a .conf-dist. 
-
-Example:
-  my $twconf = $utility->find_config (
-	  file   => 'toaster-watcher.conf', 
-	  etcdir => '/usr/local/etc',
-	)
-
- arguments required:
-   file - the .conf file to read in
-
- arguments optional:
-   etcdir - the etc directory to prefer
-   debug
-   fatal
-
- result:
-   0 - failure
-   the path to $file  
-
-
 =item find_bin
 
 Check all the "normal" locations for a binary that should be on the system and returns the full path to the binary.
 
-   $utility->find_bin( 'dos2unix', dir=>'/opt/local/bin' );
+   $util->find_bin( 'dos2unix', dir=>'/opt/local/bin' );
 
 Example: 
 
-   my $apachectl = $utility->find_bin( "apachectl", dir=>"/usr/local/sbin" );
+   my $apachectl = $util->find_bin( "apachectl", dir=>"/usr/local/sbin" );
 
 
  arguments required:
@@ -2750,7 +2798,7 @@ returns an arrayref of IP addresses on local interfaces.
 
 Verify if a process is running or not.
 
-   $utility->is_process_running($process) ? print "yes" : print "no";
+   $util->is_process_running($process) ? print "yes" : print "no";
 
 $process is the name as it would appear in the process table.
 
@@ -2760,7 +2808,7 @@ $process is the name as it would appear in the process table.
 
 
   ############################################
-  # Usage      : $utility->is_readable( file=>$file );
+  # Usage      : $util->is_readable( file=>$file );
   # Purpose    : ????
   # Returns    : 0 = no (not reabable), 1 = yes
   # Parameters : S - file - a path name to a file
@@ -2779,7 +2827,7 @@ $process is the name as it would appear in the process table.
 If the file exists, it checks to see if it is writable. If the file does not exist, it checks to see if the enclosing directory is writable. 
 
   ############################################
-  # Usage      : $utility->is_writable(file =>"/tmp/boogers");
+  # Usage      : $util->is_writable(file =>"/tmp/boogers");
   # Purpose    : make sure a file is writable
   # Returns    : 0 - no (not writable), 1 - yes (is writeable)
   # Parameters : S - file - a path name to a file
@@ -2790,7 +2838,7 @@ If the file exists, it checks to see if it is writable. If the file does not exi
 
 
   ############ fstab_list ###################
-  # Usage      : $utility->fstab_list;
+  # Usage      : $util->fstab_list;
   # Purpose    : Fetch a list of drives that are mountable from /etc/fstab.
   # Returns    : an arrayref
   # Comments   : used in backup.pl
@@ -2799,7 +2847,7 @@ If the file exists, it checks to see if it is writable. If the file does not exi
 
 =item get_dir_files
 
-   $utility->get_dir_files( dir=>$dir, debug=>1 )
+   $util->get_dir_files( dir=>$dir, debug=>1 )
 
  required arguments:
    dir - a directory
@@ -2817,7 +2865,7 @@ If the file exists, it checks to see if it is writable. If the file does not exi
 
 Returns the date split into a easy to work with set of strings. 
 
-   $utility->get_the_date( bump=>$bump, debug=>$debug )
+   $util->get_the_date( bump=>$bump, debug=>$debug )
 
  required arguments:
    none
@@ -2835,14 +2883,14 @@ Returns the date split into a easy to work with set of strings.
 	$mn = minutes
 	$ss = seconds
 
-	my ($dd, $mm, $yy, $lm, $hh, $mn, $ss) = $utility->get_the_date();
+	my ($dd, $mm, $yy, $lm, $hh, $mn, $ss) = $util->get_the_date();
 
 
 =item install_from_source
 
   usage:
 
-	$utility->install_from_source(
+	$util->install_from_source(
 		package => 'simscan-1.07',
    	    site    => 'http://www.inter7.com',
 		url     => '/simscan/',
@@ -2885,11 +2933,11 @@ tests to determine if the running process is attached to a terminal.
 
 =item logfile_append
 
-   $utility->logfile_append( file=>$file, lines=>\@lines )
+   $util->logfile_append( file=>$file, lines=>\@lines )
 
 Pass a filename and an array ref and it will append a timestamp and the array contents to the file. Here's a working example:
 
-   $utility->logfile_append( file=>$file, prog=>"proggy", lines=>["Starting up", "Shutting down"] )
+   $util->logfile_append( file=>$file, prog=>"proggy", lines=>["Starting up", "Shutting down"] )
 
 That will append a line like this to the log file:
 
@@ -2912,14 +2960,14 @@ That will append a line like this to the log file:
 
 =item mailtoaster
 
-   $utility->mailtoaster();
+   $util->mailtoaster();
 
-Downloads and installs Provision::Unix.
+Downloads and installs Mail::Toaster.
 
 
 =item mkdir_system
 
-   $utility->mkdir_system( dir => $dir, debug=>$debug );
+   $util->mkdir_system( dir => $dir, debug=>$debug );
 
 creates a directory using the system mkdir binary. Can also make levels of directories (-p) and utilize sudo if necessary to escalate.
 
@@ -2928,7 +2976,7 @@ creates a directory using the system mkdir binary. Can also make levels of direc
 
 pidfile_check is a process management method. It will check to make sure an existing pidfile does not exist and if not, it will create the pidfile.
 
-   $pidfile = $utility->pidfile_check( pidfile=>"/var/run/program.pid" );
+   $pidfile = $util->pidfile_check( pidfile=>"/var/run/program.pid" );
 
 The above example is all you need to do to add process checking (avoiding multiple daemons running at the same time) to a program or script. This is used in toaster-watcher.pl and rrdutil. toaster-watcher normally completes a run in a few seconds and is run every 5 minutes. 
 
@@ -2939,7 +2987,7 @@ However, toaster-watcher can be configured to do things like expire old messages
 
 Example:
 
-	my $pidfile = $utility->pidfile_check( pidfile=>"/var/run/changeme.pid" );
+	my $pidfile = $util->pidfile_check( pidfile=>"/var/run/changeme.pid" );
 	unless ($pidfile) {
 		warn "WARNING: couldn't create a process id file!: $!\n";
 		exit 0;
@@ -2954,9 +3002,9 @@ Example:
 Prints out a string with the regexp match bracketed. Credit to Damien Conway from Perl Best Practices.
 
  Example:
-    $utility->regexp_test( 
-		exp    => 'toast', 
-		string => 'mailtoaster rocks',
+    $util->regexp_test( 
+		exp    => 'unix', 
+		string => 'provision unix rocks',
 	);
 
  arguments required:
@@ -2973,8 +3021,8 @@ Checks to see if the old build sources are present. If they are, offer to remove
 
  Usage:
 
-   $utility->source_warning( 
-		package => "Mail-Toaster-4.10", 
+   $util->source_warning( 
+		package => "Provision-Unix-0.80", 
 		clean   => 1, 
 		src     => "/usr/local/src" 
    );
@@ -2998,7 +3046,6 @@ Tries to download a set of sources files from the site and url provided. It will
 
   usage:
 	$self->sources_get( 
-		conf    => $conf, 
 		package => 'simscan-1.07', 
 		site    => 'http://www.inter7.com',
 		url     => '/simscan/',
@@ -3018,9 +3065,9 @@ This sub proved quite useful during 2005 as many packages began to be distribute
 
 =item sudo
 
-   my $sudo = $utility->sudo();
+   my $sudo = $util->sudo();
 
-   $utility->syscmd( "$sudo rm /etc/root-owned-file" );
+   $util->syscmd( "$sudo rm /etc/root-owned-file" );
 
 Often you want to run a script as an unprivileged user. However, the script may need elevated privileges for a plethora of reasons. Rather than running the script suid, or as root, configure sudo allowing the script to run system commands with appropriate permissions.
 
@@ -3040,7 +3087,7 @@ If sudo is not installed and you're running as root, it'll offer to install sudo
 
    Just a little wrapper around system calls, that returns any failure codes and prints out the error(s) if present. A bit of sanity testing is also done to make sure the command to execute is safe. 
 
-      my $r = $utility->syscmd( "gzip /tmp/example.txt" );
+      my $r = $util->syscmd( "gzip /tmp/example.txt" );
       $r ? print "ok!\n" : print "not ok.\n";
 
     arguments required:
@@ -3061,7 +3108,7 @@ try creating a directory using perl's builtin mkdir.
 
 =item yes_or_no
 
-  my $r = $utility->yes_or_no( 
+  my $r = $util->yes_or_no( 
       "Would you like fries with that?",
       timeout  => 30
   );
@@ -3108,7 +3155,7 @@ The following are all man/perldoc pages:
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003-2008, The Network People, Inc. All Rights Reserved.
+Copyright (c) 2003-2009, The Network People, Inc. All Rights Reserved.
 
 Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 
